package detector;

import java.io.IOException;

import com.maxmind.geoip.LookupService;

import detector.movement.MovementCalculator;
import detector.movement.MovementOutputter;
import detector.reader.ReaderExecutor;

/**
 * @author Roman Tekhov
 */
class Main { 

	private static final String DEFAULT_CONF_FILE = "conf.properties";

	
	public static void main(String[] args) {		
		String confFile = args.length == 0 ? DEFAULT_CONF_FILE : args[0];
		Logger.info("Using configuration from \"" + confFile + "\"");
		
		Configuration conf = ConfigurationReader.read(confFile);
				
		LookupService lookupService = createLookupService(conf);	
		
		EntryStorage entryStorage = new EntryStorage();
		
		ReaderExecutor readerExecutor = new ReaderExecutor(conf, entryStorage);
		readerExecutor.execute();
		
		MovementCalculator movementCalculator = new MovementCalculator(entryStorage, lookupService);
		
		MovementOutputter outputter = new MovementOutputter(conf, movementCalculator);
		outputter.output();
	}
		
	
	private static LookupService createLookupService(Configuration conf) {
		try {
			return new LookupService(conf.getGeoIpDb(), LookupService.GEOIP_INDEX_CACHE);
		} catch (IOException e) {
			throw new IllegalArgumentException("Error reading GeoIP database file", e);
		}
	}

}
