package detector.movement;

import com.maxmind.geoip.Location;
import detector.Entry;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author Roman Tekhov
 */
class Movement {

  private static final DateFormat DATE_FORMAT = new SimpleDateFormat("dd.MM.yyyy HH:mm:ss");

  private String hostFrom;
  private String hostTo;
  private Date dateFrom;
  private Date dateTo;
  private Location locationFrom;
  private Location locationTo;

  private double distance = -1;
  private double time = -1;


  Movement(Entry from, Entry to) {
    this.hostFrom = from.getHost();
    this.hostTo = to.getHost();
    this.dateFrom = from.getDate();
    this.dateTo = to.getDate();
    this.locationFrom = from.getLocation();
    this.locationTo = to.getLocation();
  }


  public String getHostFrom() {
    return hostFrom;
  }

  public String getHostTo() {
    return hostTo;
  }

  public Date getDateFrom() {
    return dateFrom;
  }

  public Date getDateTo() {
    return dateTo;
  }

  public Location getLocationFrom() {
    return locationFrom;
  }

  public Location getLocationTo() {
    return locationTo;
  }


  public double getDistance() {
    if(distance == -1) {
      distance = locationFrom.distance(locationTo);
    }
    return distance;
  }

  public double getTime() {
    if(time == -1) {
      time = ((double)(dateTo.getTime() - dateFrom.getTime())) / 3600000;
    }
    return time;
  }

  public double getSpeed() {
    return getDistance() / getTime();
  }


  @Override
  public String toString() {
    return getDistance() + " km, " +
           getTime() + " h, " +
           getSpeed() + " km/h " +
           toString(hostFrom, dateFrom, locationFrom) + " -> " +
           toString(hostTo, dateTo, locationTo);
  }

  private String toString(String host, Date date, Location location) {
    return "[" + host + ", " + DATE_FORMAT.format(date) + ", " +
        location.countryCode + " " + location.countryName + " " +
        location.city + " " + location.latitude + " " +
        location.longitude + "]";
  }
}
