package detector.movement;

import java.io.IOException;
import java.io.PrintWriter;

import detector.Configuration;
import detector.Logger;
import detector.movement.MovementCalculator.MovementProcessor;

/**
 * @author Roman Tekhov
 */
public class MovementOutputter {
	
	private Configuration configuration;
	private MovementCalculator movementCalculator;
	
	private PrintWriter writer;
	private long users;
	
	
	public MovementOutputter(Configuration configuration, MovementCalculator movementCalculator) {
		this.configuration = configuration;
		this.movementCalculator = movementCalculator;
	}


	public void output() {		
		String outputFile = configuration.getOutputFile();
		Logger.info("Outputting results to file \"" + outputFile + "\"...");
		
		long start = System.currentTimeMillis();
		try {
			writer = new PrintWriter(outputFile, "utf-8");
			
			movementCalculator.calculate(new MovementProcessor() {
				
				public void process(UserMovements movements) {
					writer.println((users + 1) + ". " + movements.getUser());

					for(Movement movement : movements.getMovements()) {
						if(configuration.getMinOutputSpeed() == null 
									|| configuration.getMinOutputSpeed() <= movement.getSpeed()) {							
							writer.println(movement);
						}
					}

					writer.println();
					
					users++;
				}
			});

			writer.flush();
		} catch (IOException e) {
			Logger.error(e);
		} finally {
			if(writer != null) {
				writer.close();
			}
		}
		
		long end = System.currentTimeMillis();

		Logger.info("Results outputted in " + (end - start) + " ms. " +
				"Total number of suspicious users: " + users);
	}
	
}
