package detector.reader;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import detector.Entry;
import detector.Logger;
import detector.LogFormat;

/**
 * @author Roman Tekhov
 */
class LogParser {
		
	private Pattern pattern;
	private LogFormat format;
	
	private boolean read;
	
	
	LogParser(LogFormat format) {				
		this.format = format;
		
		read = format.getStartFromLine() == null;
		
		String regExp = format.getRegExp();
		if(regExp == null) {
			StringBuilder sb = new StringBuilder("(.+)");
			
			for(int i = 0; i < format.getPartNumber() - 1; i++) {
				sb.append(format.getDelimiter()).append("(.+)");
			}
			
			regExp = sb.toString();
		}
		
		pattern = Pattern.compile(regExp);
	}
	
	
	Entry parse(String line) {
		if(!read) {
			if(format.getStartFromLine().equalsIgnoreCase(line)) {
				read = true;
			}			
			return null;	
		} 
		
		if(format.getStopAtLine() != null && format.getStopAtLine().equalsIgnoreCase(line)) {
			read = false;
			return null;
		}
		
		Matcher matcher = pattern.matcher(line);
		
		if (matcher.matches() && format.getPartNumber() == matcher.groupCount()) {      
			String user = matcher.group(format.getUserPart());
			
			if (user == null || user.isEmpty() || format.mustIgnore(user)) {
				return null;
			}
			
			String host = matcher.group(format.getHostPart());
			int colonIndex = host.indexOf(":");
			if(colonIndex > 0) {
				host = host.substring(0, colonIndex);
			}
			
			String dateStr = matcher.group(format.getDatePart());
			Date date;
	     try {
	      DateFormat dateFormat = new SimpleDateFormat(format.getDateFormat(), format.getDateLocale());
				date = dateFormat.parse(dateStr);
			} catch (Exception e) {
				Logger.error(e);
					
				return null;
			}
			
			return new Entry(user, date, host);
    }
		
		return null;
	}

}
