package detector.reader;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

import detector.Entry;
import detector.Logger;
import detector.EntryStorage;

/**
 * @author Roman Tekhov
 */
class LogReader {
		
	private String fileName;
	private LogParser parser;	
	private EntryStorage entryStorage;
	
	
	LogReader(String fileName, LogParser parser, 
	          EntryStorage entryStorage) {
		this.fileName = fileName;
		this.parser = parser;
		this.entryStorage = entryStorage;
	}

		
	void read() {
		Logger.info("Started reading log file \"" + fileName + "\"");
		
		BufferedReader reader = null;
		
		long start = System.currentTimeMillis();
		try {
			reader = new BufferedReader(new FileReader(fileName));
			
			String line;
			while((line = reader.readLine()) != null) {
				Entry entry = parser.parse(line);
				
				if(entry != null) {
					entryStorage.addEntry(entry);
				}
			}
		} catch (IOException e) {
			Logger.error(e);
		} finally {			
			if(reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					Logger.error(e);
				}
			}
			
			long end = System.currentTimeMillis();
			Logger.info("Finished reading log file \"" + fileName +
			           "\". Time taken: " + (end - start) + " ms");
		}
	}
	
}
