package detector.reader;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import detector.Configuration;
import detector.Logger;
import detector.EntryStorage;
import detector.LogFormat;

/**
 * @author Roman Tekhov
 */
public class ReaderExecutor {

	private Configuration configuration;
	private EntryStorage entryStorage;
	
	
	public ReaderExecutor(Configuration configuration,
	                      EntryStorage entryStorage) {
		this.configuration = configuration;
		this.entryStorage = entryStorage;
	}

	
	public void execute() {				
		Map<LogFormat, List<String>> filesMap = configuration.getFilesMap();
		
		List<Thread> readerThreads = new ArrayList<Thread>();
		
		for(Map.Entry<LogFormat, List<String>> entry : filesMap.entrySet()) {		
			LogFormat format = entry.getKey();
			List<String> files = entry.getValue();
			
			Logger.info("Reading log file(s) " + files + " of format \"" 
			            + format.getName() + "\"");
			
			LogParser parser = new LogParser(format);
			
			for(String file : files) {
				LogReader reader = new LogReader(file, parser, entryStorage);
								
				Thread thread = new ReaderThread(reader);			
				thread.start();
				
				readerThreads.add(thread);
			}			
		}
		
		for(Thread thread : readerThreads) {
			try {
				thread.join();
			} catch (InterruptedException e) {
				Logger.error(e);
			}
		}
	}
	
	
	private static class ReaderThread extends Thread {
		
		private LogReader reader;

		ReaderThread(LogReader reader) {
			this.reader = reader;
		}

		@Override
		public void run() {
			reader.read();
		}
	}

}
