package detector.test;

import java.io.PrintWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Locale;
import java.util.Random;

/**
 * @author Roman Tekhov
 */
public class LogGenerator {

  public static void main(String[] args) {
    String[] fileNames = args[0].split(",");

    PrintWriter[] writers = new PrintWriter[fileNames.length];

    try {
      for (int i = 0; i < fileNames.length; i++) {
        writers[i] = new PrintWriter(fileNames[i]);
      }

      int userNumber = Integer.parseInt(args[1]);
      int fraudUserNumber = Integer.parseInt(args[2]);

      User[] users = new User[userNumber];
      for (int i = 0; i < userNumber; i++) {
        boolean fraud = fraudUserNumber > 0;
        users[i] = new User("u" + (i + 1), generateRandomIp(), fraud);

        if (fraud) {
          fraudUserNumber--;
        }
      }

      DateFormat dateFormat = new SimpleDateFormat("dd/MMM/yyyy:HH:mm:ss Z", Locale.ENGLISH);
      Calendar calendar = Calendar.getInstance();
      calendar.set(Calendar.YEAR, 2010);
      calendar.set(Calendar.MONTH, Calendar.MAY);
      calendar.set(Calendar.DAY_OF_MONTH, 1);
      calendar.set(Calendar.HOUR_OF_DAY, 0);
      calendar.set(Calendar.MINUTE, 0);
      calendar.set(Calendar.SECOND, 0);

      Random random = new Random();
      int entryNumber = Integer.parseInt(args[3]);
      for (int i = 0; i < entryNumber; i++) {
        User user = users[random.nextInt(users.length)];
        String ip = user.isFraud() && random.nextBoolean() ? generateRandomIp() : user.getIp();
        String date = dateFormat.format(calendar.getTime());

        String entry = ip + " - " + user.getName() + " [" + date + "] \"GET /favicon.ico HTTP/1.1\" 404 209";

        PrintWriter writer = writers[random.nextInt(writers.length)];
        writer.println(entry);

        calendar.add(Calendar.SECOND, 5);
      }

      for (PrintWriter writer : writers) {
        writer.flush();
      }
    } catch (Exception e) {
      e.printStackTrace();
    } finally {
      for (PrintWriter writer : writers) {
        if (writer != null) {
          writer.close();
        }
      }
    }
  }


  private static String generateRandomIp() {
    Random r = new Random();

    int part1 = r.nextInt(223 - 192 + 1) + 192;
    int part2 = r.nextInt(256);
    int part3 = r.nextInt(256);
    int part4 = r.nextInt(256);

    return part1 + "." + part2 + "." + part3 + "." + part4;
  }


  private static class User {

    private String name;
    private String ip;
    private boolean fraud;

    User(String name, String ip, boolean fraud) {
      this.name = name;
      this.ip = ip;
      this.fraud = fraud;
    }

    String getName() {
      return name;
    }

    String getIp() {
      return ip;
    }

    boolean isFraud() {
      return fraud;
    }
  }
}
